@@ -63,6 +63,8 @@ pub enum Futures {
     AllForceOrders,
     AllOpenOrders,
     Order,
+    PositionRisk,
+    Balance,
     PositionSide,
     OpenInterest,
     OpenInterestHist,
@@ -127,6 +129,8 @@ impl From<API> for String {
                     Futures::AllOpenOrders => "/fapi/v1/allOpenOrders",
                     Futures::PositionSide => "/fapi/v1/positionSide/dual",
                     Futures::Order => "/fapi/v1/order",
+                    Futures::PositionRisk => "/fapi/v2/positionRisk",
+                    Futures::Balance => "/fapi/v2/balance",
                     Futures::OpenInterest => "/fapi/v1/openInterest",
                     Futures::OpenInterestHist => "/futures/data/openInterestHist",
                     Futures::TopLongShortAccountRatio => "/futures/data/topLongShortAccountRatio",
