@@ -6,7 +6,7 @@ use crate::client::Client;
 use crate::api::{API, Futures};
 use crate::model::Empty;
 use crate::account::{OrderSide, TimeInForce};
-use super::model::{ChangeLeverageResponse, Transaction};
+use super::model::{ChangeLeverageResponse, Transaction, CanceledOrder, Position, AccountBalance};
 
 
 #[derive(Clone)]
@@ -164,7 +164,7 @@ impl FuturesAccount {
     }
 
     // Place a MARKET order - BUY
-    pub fn market_buy<S, F>(&self, symbol: S, qty: F, time_in_force: TimeInForce) -> Result<Transaction>
+    pub fn market_buy<S, F>(&self, symbol: S, qty: F) -> Result<Transaction>
     where
         S: Into<String>,
         F: Into<f64>,
@@ -174,7 +174,7 @@ impl FuturesAccount {
             side: OrderSide::Buy,
             position_side: None,
             order_type: OrderType::Market,
-            time_in_force: Some(time_in_force),
+            time_in_force: None,
             qty: Some(qty.into()),
             reduce_only: None,
             price: None,
@@ -191,7 +191,7 @@ impl FuturesAccount {
     }
 
     // Place a MARKET order - SELL
-    pub fn market_sell<S, F>(&self, symbol: S, qty: F, time_in_force: TimeInForce) -> Result<Transaction>
+    pub fn market_sell<S, F>(&self, symbol: S, qty: F) -> Result<Transaction>
     where
         S: Into<String>,
         F: Into<f64>,
@@ -201,7 +201,7 @@ impl FuturesAccount {
             side: OrderSide::Sell,
             position_side: None,
             order_type: OrderType::Market,
-            time_in_force: Some(time_in_force),
+            time_in_force: None,
             qty: Some(qty.into()),
             reduce_only: None,
             price: None,
@@ -217,6 +217,18 @@ impl FuturesAccount {
         self.client.post_signed(API::Futures(Futures::Order), request)
     }
 
+    pub fn cancel_order<S>(&self, symbol: S, order_id: u64) -> Result<CanceledOrder> 
+    where 
+        S: Into<String>
+    {
+        let mut parameters = BTreeMap::new();
+        parameters.insert("symbol".into(), symbol.into());
+        parameters.insert("orderId".into(), order_id.to_string());
+        
+        let request = build_signed_request(parameters, self.recv_window)?;
+        self.client.delete_signed(API::Futures(Futures::Order), Some(request))
+    }
+
     fn build_order(&self, order: OrderRequest) -> BTreeMap<String, String> {
         let mut parameters = BTreeMap::new();
         parameters.insert("symbol".into(), order.symbol);
@@ -260,6 +272,23 @@ impl FuturesAccount {
         parameters
     }
 
+    pub fn position_information<S>(&self, symbol: S) -> Result<Vec<Position>>
+        where S: Into<String>
+    {
+        let mut parameters = BTreeMap::new();
+        parameters.insert("symbol".into(), symbol.into());
+
+        let request = build_signed_request(parameters, self.recv_window)?;
+        self.client.get_signed(API::Futures(Futures::PositionRisk), Some(request))
+    }
+
+    pub fn account_balance(&self) -> Result<Vec<AccountBalance>> {
+        let parameters = BTreeMap::new();
+
+        let request = build_signed_request(parameters, self.recv_window)?;
+        self.client.get_signed(API::Futures(Futures::Balance), Some(request))
+    }
+
     pub fn change_initial_leverage<S>(&self, symbol: S, leverage: u8) -> Result<ChangeLeverageResponse>
     where
         S: Into<String>
